import React from 'react';
import Taro from '@tarojs/taro';
import md5 from 'md5';
import { login, signin, currentUser } from '@/services/wxma';

export default function useUser() {
  const [person, setPerson] = React.useState();
  const [user, setUser] = React.useState();
  const [duty, setDuty] = React.useState();

  const maLogin = (code) => {
    login(code).then(res => {
      setPerson(res.person);
      Taro.setStorage({ key: 'personId', data: res.person.personId })
      Taro.setStorage({ key: 'sessionKey', data: res.sessionKey })
    });
  }

  const updateDuty = (d) => {
    setDuty(d);
    Taro.setStorageSync('duty', d);
  }

  const initDuty = (u) => {
    const d = Taro.getStorageSync('duty');
    const dutyList = u?.dutyList || [];
    if (d) {
      if (dutyList.indexOf(d) < 0) {
        updateDuty(dutyList[0]);
      } else {
        updateDuty(d);
      }
    } else {
      updateDuty(dutyList[0]);
    }
  }

  const maSignIn = (params) => {
    const data = {
      ...params,
      password: md5(params.password)
    };

    return signin(data).then(res => {
      setUser(res.user);
      initDuty(res.user);
    })
  }

  const current = () => {
    currentUser().then(res => {
      setUser(res.user);
      initDuty(res.user);
    })
  }

  return {
    user,
    person,
    current,
    duty,
    signin: maSignIn,
    login: maLogin,
    updateDuty,
  }
}
